@@ -3,8 +3,7 @@ from typing import Protocol
 
 
 class NamingCase(Protocol):
-    def __call__(self, name: str) -> str:
-        ...
+    def __call__(self, name: str) -> str: ...
 
 
 @dataclasses.dataclass(frozen=True, slots=True, kw_only=True)
@@ -39,11 +38,11 @@ class CamelCase:
 
 
 @dataclasses.dataclass(frozen=True, slots=True, kw_only=True)
-class _Default:
+class UpperSnakeCase:
     def __call__(self, name: str) -> str:
-        return name
+        return name.upper()
 
 
 CAPITAL_CAMEL_CASE = CapitalCamelCase(capitalize_words=frozenset())
 CAMEL_CASE = CamelCase(capitalize_words=frozenset())
-DEFAULT_CASE = _Default()
+UPPER_SNAKE_CASE = UpperSnakeCase()
